@@ -107,7 +107,10 @@ def parse(
             key = "{} (max)".format(col)
             log_keys.add(key)
             index = log[col].idxmax()
-            if key_of_interest is not None:
+            if (
+                key_of_interest is not None
+                and key_of_interest[:-6] in log.columns
+            ):
                 if key_of_interest.endswith(" (max)"):
                     index = log[key_of_interest[:-6]].idxmax()
                 elif key_of_interest.endswith(" (min)"):
@@ -121,7 +124,10 @@ def parse(
             key = "{} (min)".format(col)
             log_keys.add(key)
             index = log[col].idxmax()
-            if key_of_interest is not None:
+            if (
+                key_of_interest is not None
+                and key_of_interest[:-6] in log.columns
+            ):
                 if key_of_interest.endswith(" (max)"):
                     index = log[key_of_interest[:-6]].idxmax()
                 elif key_of_interest.endswith(" (min)"):
